==> armadillo-0.1.0.zip: src/jp/sourceforge/armadillo/TarArchiver.java <==
package jp.sourceforge.armadillo;

import java.io.*;

import jp.sourceforge.armadillo.io.*;
import jp.sourceforge.armadillo.tar.*;

/**
 * TarA[JCoB
 * AntAPIgpTAR`̃A[JCu쐬B
 */
public final class TarArchiver implements Archiver {

    private TarOutputStream tos;
    private boolean includesDirectory;

    /**
     * TarArchiver̐B
     * @param os OutputStream
     */
    public TarArchiver(OutputStream os) {
        this.tos = new TarOutputStream(os);
        this.includesDirectory = true;
    }

    /**
     * includesDirectory̐ݒB
     * @param includesDirectory includesDirectory
     */
    public void setIncludesDirectory(boolean includesDirectory) {
        this.includesDirectory = includesDirectory;
    }

    /* (overridden)
     * @see jp.sourceforge.armadillo.Archiver#addEntry(jp.sourceforge.armadillo.ArchiveEntry, java.io.InputStream, long)
     */
    public void addEntry(ArchiveEntry ae, InputStream is, long length) throws IOException {
        if (ae.isDirectory()) {
            // fBNg
            if (!includesDirectory) {
                return;
            }
            TarEntry entry = new TarEntry(ae.getName());
            entry.setMode(TarEntry.DEFAULT_DIR_MODE);
            entry.setLastModified(ae.getLastModified());
            tos.putNextEntry(entry);
            tos.closeEntry();
        } else {
            // t@C
            TarEntry entry = new TarEntry(ae.getName());
            entry.setSize(length);
            entry.setLastModified(ae.getLastModified());
            tos.putNextEntry(entry);
            IOUtilities.transferAll(is, tos);
            tos.closeEntry();
        }
    }

    /* (overridden)
     * @see java.io.Closeable#close()
     */
    public void close() throws IOException {
        tos.close();
    }

}

==> armadillo-0.1.1.zip: src/jp/sourceforge/armadillo/TarArchiver.java <==
package jp.sourceforge.armadillo;

import java.io.*;

import jp.sourceforge.armadillo.io.*;
import jp.sourceforge.armadillo.tar.*;

/**
 * TarA[JCoB
 * AntAPIgpTAR`̃A[JCu쐬B
 */
public final class TarArchiver implements Archiver {

    private TarOutputStream tos;
    private boolean includesDirectory;

    /**
     * TarArchiver̐B
     * @param os OutputStream
     */
    public TarArchiver(OutputStream os) {
        this.tos = new TarOutputStream(os);
        this.includesDirectory = true;
    }

    /**
     * includesDirectory̐ݒB
     * @param includesDirectory includesDirectory
     */
    public void setIncludesDirectory(boolean includesDirectory) {
        this.includesDirectory = includesDirectory;
    }

    /* (overridden)
     * @see jp.sourceforge.armadillo.Archiver#addEntry(jp.sourceforge.armadillo.ArchiveEntry, java.io.InputStream, long)
     */
    public void addEntry(ArchiveEntry ae, InputStream is, long length) throws IOException {
        long size;
        if (ae.isDirectory()) {
            // fBNg
            if (!includesDirectory) {
                return;
            }
            TarEntry entry = new TarEntry(ae.getName());
            entry.setMode(TarEntry.DEFAULT_DIR_MODE);
            entry.setLastModified(ae.getLastModified());
            tos.putNextEntry(entry);
            tos.closeEntry();
            size = 0L;
        } else {
            // t@C
            TarEntry entry = new TarEntry(ae.getName());
            entry.setSize(length);
            entry.setLastModified(ae.getLastModified());
            tos.putNextEntry(entry);
            size = IOUtilities.transferAll(is, tos);
            entry.setSize(size);
            tos.closeEntry();
        }
        ae.setSize(size);
        ae.setCompressedSize(size);
        ae.setAdded(true);
    }

    /* (overridden)
     * @see java.io.Closeable#close()
     */
    public void close() throws IOException {
        tos.close();
    }

}
